use crate::cli::Cli;
use clap::{Args, Subcommand};
use std::io;

#[derive(Subcommand)]
pub enum BackupCommands {
    Create(BackupCreateArgs),
    List,
}

#[derive(Args)]
pub struct BackupArgs {
    #[command(subcommand)]
    pub command: BackupCommands,
}

#[derive(Args)]
pub struct BackupCreateArgs {
    /// What layer to create a backup in
    layer: String,
}

impl BackupArgs {
    pub fn run(&self, cli: &Cli) -> io::Result<()> {
        match &self.command {
            BackupCommands::Create(args) => args.run(cli),
            BackupCommands::List => Ok(()),
        }
    }
}

impl BackupCreateArgs {
    pub fn run(&self, cli: &Cli) -> io::Result<()> {
        let mut meta = cli.meta()?;

        if let Some(res) = meta.create_backup(&self.layer) {
            res
        } else {
            Err(io::Error::new(io::ErrorKind::Other, "Unknown layer"))
        }
    }
}
